IQueue<IRunFunction, IOptions> class abstract

Implementers

Constructors

IQueue()

Properties

hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
no setter

Methods

dequeue({dynamic key}) → IRunFunction
enqueue(IRunFunction run, {int priority, dynamic key}) → void
filter(int priority) → List<IRunFunction>
indexOf(dynamic key) → int
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited